__package_name__ = "gdal-utils"
gdal_utils_version = (3, 12, 3, 0)
__version__ = ".".join(str(i) for i in gdal_utils_version)
__author__ = "Frank Warmerdam"
__author_email__ = "warmerdam@pobox.com"
__maintainer__ = "Idan Miara"
__maintainer_email__ = "idan@miara.com"
__description__ = (
    "gdal-utils: An extension library for GDAL - Geospatial Data Abstraction Library"
)
__license_type__ = "MIT"
__url__ = "http://www.gdal.org"
